Module github

Module github 

Available on crate feature github only.
GitHub releases

Structs

AsyncUpdateasync
Async-only updater returned by UpdateBuilder::build_async.
ReleaseList
ReleaseList provides a builder api for querying a GitHub repo, returning a Vec of available Releases
ReleaseListBuilder
ReleaseList Builder
Update
Updates to a specified or latest release distributed via GitHub
UpdateBuilder
github::Update builder