#[non_exhaustive]pub enum ArchiveKind {
Tar(Option<Compression>),
Plain(Option<Compression>),
Zip,
}Expand description
The archive format of a release asset, as detected from its file extension.
#[non_exhaustive], and the Tar/Zip variants are gated on the archive-tar / archive-zip
features: if the matching feature is off the variant does not exist and detect_archive for
that extension returns Error::ArchiveNotEnabled instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Tar(Option<Compression>)
Available on crate feature
archive-tar only.A tarball, optionally compressed (e.g. .tar, .tar.gz, .tar.xz). Requires archive-tar.
Plain(Option<Compression>)
A bare file, optionally compressed (e.g. a plain binary, or a .gz / .xz of one).
Zip
Available on crate feature
archive-zip only.A zip archive (.zip). Requires archive-zip.