Move

Struct Move 

#[non_exhaustive]
pub struct Move { /* private fields */ }
Moves a file from the given path to the specified destination.

source and dest must be on the same filesystem. If replace_using_temp is specified, the destination file will be replaced using the given temporary path. If the existing dest file is a currently running long running program, replace_using_temp may run into errors cleaning up the temp dir. If that’s the case for your use-case, consider not specifying a temp dir to use.

  • Errors:
    • Io - copying / renaming

Implementations

Source

impl Move

pub fn from_source(source: impl AsRef<Path>) -> Move

Specify source file. Accepts anything path-like, storing an owned PathBuf.

pub fn replace_using_temp(&mut self, temp: impl AsRef<Path>) -> &mut Self

If specified and the destination file already exists, the “destination” file will be moved to the given temporary location before the “source” file is moved to the “destination” file.

In the event of an io error while renaming “source” to “destination”, the temporary file will be moved back to “destination”.

The temp dir must be explicitly provided since rename operations require files to live on the same filesystem.

pub fn to_dest(&self, dest: impl AsRef<Path>) -> Result<()>

Move source file to specified destination