#[non_exhaustive]pub struct Update { /* private fields */ }Available on crate feature
github only.Expand description
Updates to a specified or latest release distributed via GitHub
Implementations
Sourceimpl Update
impl Update
Sourcepub fn update(&self) -> Result<VersionStatus>
pub fn update(&self) -> Result<VersionStatus>
Display release information and update the current binary to the latest release,
pending confirmation. Returns a VersionStatus. See
ReleaseUpdate::update.
Sourcepub fn update_extended(&self) -> Result<ReleaseStatus>
pub fn update_extended(&self) -> Result<ReleaseStatus>
Same as update but returns a ReleaseStatus
with the full release details.
Sourcepub fn get_latest_release(&self) -> Result<Releases>
pub fn get_latest_release(&self) -> Result<Releases>
Fetch the single newest release (raw, unfiltered). See
ReleaseUpdate::get_latest_release.
Sourcepub fn get_newer_releases(&self) -> Result<Releases>
pub fn get_newer_releases(&self) -> Result<Releases>
Fetch the releases newer than the current version. See
ReleaseUpdate::get_newer_releases.
Sourcepub fn get_release_version(&self, ver: &str) -> Result<Release>
pub fn get_release_version(&self, ver: &str) -> Result<Release>
Fetch details of the release matching ver. See
ReleaseUpdate::get_release_version.
Sourcepub fn is_update_available(&self) -> Result<Option<Release>>
pub fn is_update_available(&self) -> Result<Option<Release>>
Whether a release newer than the current version is available, returning it if so.
A convenience over get_newer_releases: returns the
newest strictly-newer Release, or None when already up to date.